@@ -146,6 +146,49 @@ gps_location_changed (LocationGPSDevice *device, gpointer userdata)
     }
 }
 /*******************************************************************************/ 
+static void 
+gps_location_started (LocationGPSDControl *control, gpointer userdata)
+{
+ initial_gps_connect();
+}
+static void 
+gps_location_stopped (LocationGPSDControl *control, gpointer userdata)
+{
+ deinitial_gps_connect();
+}
+
+/*******************************************************************************/ 
+void
+initial_gps_control(void)
+{ 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    app->gps_control = location_gpsd_control_get_default();
+    app->gps_run = g_signal_connect (app->gps_control, "gpsd_running", G_CALLBACK (gps_location_started), NULL);
+    app->gps_stop = g_signal_connect (app->gps_control, "gpsd_stopped", G_CALLBACK (gps_location_stopped), NULL);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif    
+}
+/*******************************************************************************/ 
+void
+deinitial_gps_control(void)
+{ 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    deinitial_gps_connect();
+    g_signal_handler_disconnect (app->gps_control,app->gps_run);
+    g_signal_handler_disconnect (app->gps_control,app->gps_stop);
+    g_object_unref(app->gps_control);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif    
+}
+/*******************************************************************************/
 void
 initial_gps_connect(void)
 { 
@@ -166,8 +209,10 @@ deinitial_gps_connect(void)
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    g_signal_handler_disconnect (app->gps_device,app->gps_id_connection);
-    g_object_unref(app->gps_device);
+    if (app->gps_device){
+	g_signal_handler_disconnect (app->gps_device,app->gps_id_connection);
+	g_object_unref(app->gps_device);
+    }	
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
