@@ -67,7 +67,7 @@ const WeatherSource	weather_sources[MAX_WEATHER_SOURCE_NUMBER] = {
     },
     {	"weather.com - 2",
 	"/usr/share/omweather/db/weather_com/",
-	"http://xoap.weather.com/weather/local/%s?cc=*&unit=m&dayf=10",
+	"http://xml.weather.com/weather/local/%s?cm_ven=1CW&site=wx.com-bar&cm_ite=wx-cc&par=1CWFFv1.1.8&cm_pla=wx.com-bar&cm_cat=FFv1.1.8&unit=m&dayf=10&cc=*",
 	parse_weather_com_xml
     },
     {	"rp5.ru",
